==> huaweicloudsdkcdm-3.1.139-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/show_flavors_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFlavorsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'dbname': 'str',
        'versions': 'list[CdmClusterDatastoreVersion]'
    }

    attribute_map = {
        'id': 'id',
        'dbname': 'dbname',
        'versions': 'versions'
    }

    def __init__(self, id=None, dbname=None, versions=None):
        """ShowFlavorsResponse

        The model defined in huaweicloud sdk

        :param id: 服务ID，用于区分不同服务。
        :type id: str
        :param dbname: db名称，一般为cdm。
        :type dbname: str
        :param versions: 版本信息列表。
        :type versions: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        
        super(ShowFlavorsResponse, self).__init__()

        self._id = None
        self._dbname = None
        self._versions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if dbname is not None:
            self.dbname = dbname
        if versions is not None:
            self.versions = versions

    @property
    def id(self):
        """Gets the id of this ShowFlavorsResponse.

        服务ID，用于区分不同服务。

        :return: The id of this ShowFlavorsResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShowFlavorsResponse.

        服务ID，用于区分不同服务。

        :param id: The id of this ShowFlavorsResponse.
        :type id: str
        """
        self._id = id

    @property
    def dbname(self):
        """Gets the dbname of this ShowFlavorsResponse.

        db名称，一般为cdm。

        :return: The dbname of this ShowFlavorsResponse.
        :rtype: str
        """
        return self._dbname

    @dbname.setter
    def dbname(self, dbname):
        """Sets the dbname of this ShowFlavorsResponse.

        db名称，一般为cdm。

        :param dbname: The dbname of this ShowFlavorsResponse.
        :type dbname: str
        """
        self._dbname = dbname

    @property
    def versions(self):
        """Gets the versions of this ShowFlavorsResponse.

        版本信息列表。

        :return: The versions of this ShowFlavorsResponse.
        :rtype: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this ShowFlavorsResponse.

        版本信息列表。

        :param versions: The versions of this ShowFlavorsResponse.
        :type versions: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        self._versions = versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFlavorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdm-3.1.150-py2.py3-none-any.whl: huaweicloudsdkcdm/v1/model/show_flavors_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowFlavorsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'dbname': 'str',
        'versions': 'list[CdmClusterDatastoreVersion]'
    }

    attribute_map = {
        'id': 'id',
        'dbname': 'dbname',
        'versions': 'versions'
    }

    def __init__(self, id=None, dbname=None, versions=None):
        r"""ShowFlavorsResponse

        The model defined in huaweicloud sdk

        :param id: 服务ID，用于区分不同服务。
        :type id: str
        :param dbname: db名称，一般为cdm。
        :type dbname: str
        :param versions: 版本信息列表。
        :type versions: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        
        super(ShowFlavorsResponse, self).__init__()

        self._id = None
        self._dbname = None
        self._versions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if dbname is not None:
            self.dbname = dbname
        if versions is not None:
            self.versions = versions

    @property
    def id(self):
        r"""Gets the id of this ShowFlavorsResponse.

        服务ID，用于区分不同服务。

        :return: The id of this ShowFlavorsResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this ShowFlavorsResponse.

        服务ID，用于区分不同服务。

        :param id: The id of this ShowFlavorsResponse.
        :type id: str
        """
        self._id = id

    @property
    def dbname(self):
        r"""Gets the dbname of this ShowFlavorsResponse.

        db名称，一般为cdm。

        :return: The dbname of this ShowFlavorsResponse.
        :rtype: str
        """
        return self._dbname

    @dbname.setter
    def dbname(self, dbname):
        r"""Sets the dbname of this ShowFlavorsResponse.

        db名称，一般为cdm。

        :param dbname: The dbname of this ShowFlavorsResponse.
        :type dbname: str
        """
        self._dbname = dbname

    @property
    def versions(self):
        r"""Gets the versions of this ShowFlavorsResponse.

        版本信息列表。

        :return: The versions of this ShowFlavorsResponse.
        :rtype: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        r"""Sets the versions of this ShowFlavorsResponse.

        版本信息列表。

        :param versions: The versions of this ShowFlavorsResponse.
        :type versions: list[:class:`huaweicloudsdkcdm.v1.CdmClusterDatastoreVersion`]
        """
        self._versions = versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowFlavorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
